#!/usr/bin/python
#
# Copyright 2017 Google Inc. All Rights Reserved.
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#      http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.

"""This example lists queries for the specified customer."""

import argparse
import pprint
import sys

from googleapiclient.errors import HttpError
import samples_util


DEFAULT_CUSTOMER_ID = 'INSERT_DEFAULT_CUSTOMER_ID_HERE'


def main(full_circle_query, customer_id, include_query_text, page_size):
  next_page = True

  while next_page:
    try:
      response = full_circle_query.queries().list(
          customerId=customer_id,
          includeQueryText=include_query_text,
          pageSize=page_size,
          pageToken=next_page).execute()
    except HttpError as e:
      print e
      sys.exit(1)

    if 'queries' in response:
      print 'Found the following queries for customer ID "%s":' % customer_id
      for query in response['queries']:
        pprint.pprint(query)
    elif next_page is True:
      print 'No queries found for customerId "%s".' % customer_id

    next_page = response.get('nextPageToken', False)


if __name__ == '__main__':
  parser = argparse.ArgumentParser(
      description='Retrieves list of queries for given Ads Data Hub customer.')
  parser.add_argument(
      '-c', '--customer_id', default=DEFAULT_CUSTOMER_ID,
      help=('The ID of the Ads Data Hub customer for which you are listing '
            'queries.'))
  parser.add_argument(
      '-i', '--include_query_text', type=bool, default=True,
      help=('Determines whether queries returned in the response return fields '
            'other than queryName. If true, other fields such as queryText '
            'will be included. In this example, this is set to True by '
            'default.'))
  parser.add_argument(
      '-p', '--page_size', type=int, default=samples_util.MAX_PAGE_SIZE,
      help='The maximum number of entries to be returned on one result page.')
  args = parser.parse_args()

  try:
    service = samples_util.GetService()
  except IOError, ex:
    print 'Unable to create ads data hub service - %s' % ex
    print 'Did you specify the client secrets file in samples_util.py?'
    sys.exit(1)

  main(service, args.customer_id, args.include_query_text, args.page_size)
