#!/usr/bin/python
#
# Copyright 2017 Google Inc. All Rights Reserved.
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#      http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.

"""This example runs a query with the specified name.

Note that this example is intended to run the query created in create_query.py.
Some adjustments to the QueryExecutionSpec may be required for this example to
start a different query.
"""

import argparse
import pprint
import sys

from googleapiclient.errors import HttpError
import samples_util


DEFAULT_CUSTOMER_ID = 'INSERT_DEFAULT_CUSTOMER_ID_HERE'
DEFAULT_QUERY_NAME = 'INSERT_DEFAULT_QUERY_NAME_HERE'
DEFAULT_DEST_TABLE = 'INSERT_DEFAULT_DEST_TABLE_HERE'
DEFAULT_ADWORDS_CUSTOMER_ID = 'INSERT_DEFAULT_ADWORDS_CUSTOMER_ID_HERE'
DEFAULT_START_DATE = 'INSERT_DEFAULT_START_DATE_HERE'
DEFAULT_END_DATE = 'INSERT_DEFAULT_END_DATE_HERE'


def main(full_circle_query, query_name, body):
  try:
    # Execute the request.
    operation = full_circle_query.queries().start(
        queryName=query_name, body=body).execute()
  except HttpError as e:
    print e
    sys.exit(1)

  print 'Running query with name "%s" via the following operation:' % query_name
  pprint.pprint(operation)


if __name__ == '__main__':
  parser = argparse.ArgumentParser(
      description=('Runs a query with the given name. Note that this example '
                   'is intended to run the query created in create_query.py.'))
  parser.add_argument(
      '-c', '--customer_id', default=DEFAULT_CUSTOMER_ID,
      help=('The ID of the customer for which this query is being run. This '
            'may be excluded if the authenticated user only has access to one '
            'customer account.'))
  parser.add_argument(
      '-n', '--query_name', default=DEFAULT_QUERY_NAME,
      help='The unique name associated with the query to be run.')
  parser.add_argument(
      '-d', '--dest_table', default=DEFAULT_DEST_TABLE,
      help=('The destination table to store the query results, with format '
            '"project:dataset.table_name". Your Ads Data Hub service account '
            'must have edit permissions for the dataset. If "project:dataset" '
            'is not specified, it defaults to your Ads Data Hub shared '
            'dataset.'))
  parser.add_argument(
      '-a', '--adwords_customer_id', default=DEFAULT_ADWORDS_CUSTOMER_ID,
      help=('An AdWords customer ID to be used as a parameter for the query. '
            'Note that this example is intended to run the query created in '
            'create_query.py, for which this parameter is required.'))
  parser.add_argument(
      '-e', '--end_date', default=DEFAULT_END_DATE,
      help=('The (inclusive) end date for the date range of the query, which '
            'will be accepted in this example in YYYY-MM-DD format.'))
  parser.add_argument(
      '-s', '--start_date', default=DEFAULT_START_DATE,
      help=('The (inclusive) start date for the date range of the query, which '
            'will be accepted in this example in YYYY-MM-DD format.'))
  parser.add_argument(
      '-r', '--role_name', required=False,
      help=('Name of the role for which the query is being run. If absent, the '
            'default role for the customer will be used.'))
  parser.add_argument(
      '-t', '--time_zone', required=False,
      help=('An optional parameter to specify the time zone, which will be '
            'applied to the start and end dates. If not specified, this will '
            'default to "America/Los_Angeles", or Pacific Standard Time.'))
  args = parser.parse_args()

  try:
    service = samples_util.GetService()
  except IOError, ex:
    print 'Unable to create ads data hub service - %s' % ex
    print 'Did you specify the client secrets file in samples_util.py?'
    sys.exit(1)

  query_start_body = {
      'spec': {
          'startDate': args.start_date,
          'endDate': args.end_date,
          'timeZone': args.time_zone,
          'parameterValues': {
              'customer_id': {
                  'value': args.adwords_customer_id
              }
          },
          'destTable': args.dest_table,
          'fullCircleCustomerId': args.customer_id,
          'roleName': args.role_name
      }
  }

  main(service, args.query_name, query_start_body)
